import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * A Mover is an actor that also has 'move' and 'turn' ability. Both moving and turning 
 * are relative to its current position. When moving, the Mover will move in the direction 
 * it is currently facing.
 * 
 * Both 'move' and 'turn' methods are available with or without parameters.
 * 
 * The 'Mover' class is a subclass of Actor. It can be used by creating subclasses, or
 * copied into scenarios and edited inline.
 * 
 * The initial direction is to the right. Thus, this class works best with images that
 * face right when not rotated.
 * 
 * This class can also check whether we are close to the edge of the world.
 * 
 * @author Michael Kolling
 * @version 1.0 (July 2007)
 */
public class Mover extends Actor
{
    private static final double WALKING_SPEED = 5.0;
    private int tamX;
    private int tamY;
  

    /**
     * se inicilaizan las posiciones de los objetos
     */
    public Mover(int tx, int ty)
    {
        tamX=tx;
        tamY=ty;
    }
    
    public void turn(int angle)
    {
        setRotation(getRotation() + angle);
    }
    

    /**
     * Move a bit forward in the current direction.
     */
    public void move()
    {
        move(WALKING_SPEED);
    }

    
    /**
     * Move a specified distance forward in the current direction.
     */
    public void move(double distance)
    {
        double angle = Math.toRadians( getRotation() );
        int x = (int) Math.round(getX() + Math.cos(angle) * distance);
        int y = (int) Math.round(getY() + Math.sin(angle) * distance);
        
        setLocation(x, y);
    }

    
    /**
     * Test if we are close to one of the edges of the world. Return true is we are.
     */
    public boolean atWorldEdge()
    {
        if(getX() < 20 || getX() > getWorld().getWidth() - 20)
            return true;
        if(getY() < 20 || getY() > getWorld().getHeight() - 20)
            return true;
        else
            return false;
    }
     /**
      * Me dice si el objeto se puede mover hacia las diferentes 
      * posiciones
      */
    public boolean canMove(int direccion)
    {
        boolean res=false; 
        switch(direccion)
        {
            case 1 : //izquierda
                res=izquierda();
                break;
            case 2 ://arriba
                res=arriva();
                break;
            case 3: //derecha
                res=derecha();
                break;
            case 4 ://abajo
                res=abajo();
                break;
            case 5 : //diagonal hacia abjo
                  res=diagonalAbajo();
                  break;
        }
       return(res);
    }
    /**
     * se inicializa la bandera y las x y y del objeto se ponene en variables
     * esas se incrementan o decrementan segun el caso y se checa si se puede mover
     * se cambia la bandera
     */
    public boolean diagonalAbajo()
    {
        boolean res=false;
        int x=getX();
        int y=getY();
        World mundo=getWorld();
        x-=2;
          if(x>(0+tamX)&&y<mundo.getHeight()-tamY)
            res=true;
        return(res);
    }
    
    /**
     * se inicializa la bandera y las x y y del objeto se ponene en variables
     * esas se incrementan o decrementan segun el caso y se checa si se puede mover
     * se cambia la bandera
     */
    public boolean izquierda()
    {
        boolean res=false;
        int x=getX();
         x-=1;
         if(x>(0+tamX))
            res=true;
        return(res);
    }
    
    /**
     * se inicializa la bandera y las x y y del objeto se ponene en variables
     * esas se incrementan o decrementan segun el caso y se checa si se puede mover
     * se cambia la bandera
     */
    public boolean derecha()
    {
        boolean res=false;        
        World mundo=getWorld();
        int x=getX();
         x+=1;
         if(x<(mundo.getWidth()-tamX))
            res=true;
        return(res);
    }
    
    /**
     * se inicializa la bandera y las x y y del objeto se ponene en variables
     * esas se incrementan o decrementan segun el caso y se checa si se puede mover
     * se cambia la bandera
     */
    public boolean arriva()
    {
        boolean res=false;        
        int y=getY();
         y-=1;
         if(y>(0+tamY))
            res=true;
        return(res);
    }
    
    /**
     * se inicializa la bandera y las x y y del objeto se ponene en variables
     * esas se incrementan o decrementan segun el caso y se checa si se puede mover
     * se cambia la bandera
     */
    public boolean abajo()
    {
        boolean res=false;        
        World mundo=getWorld();
        int y=getY();
         y+=1;
         if(y<(mundo.getHeight()-tamY)+tamY/2)
            res=true;
        return(res);
    }
}

